Learn R Programming

covid19tunisia (version 0.1.0)

get_info_covid19tunisia: Get information about the datasets provided by covid19tunisia

Description

Get information about the datasets provided by covid19tunisia

Usage

get_info_covid19tunisia()

Arguments

Value

A tibble with information about where the data is pulled from, details about the dataset, what the data types are, etc.

Examples

Run this code
get_info_covid19tunisia()

Run the code above in your browser using DataLab